@@ -1,9 +1,11 @@
 import sys
 import typing
 
+GenericType = typing.TypeVar("GenericType")
+
 
 def log2vis(msgs, settings):
-    '''
+    ''' 
 
     '''
 
@@ -11,7 +13,7 @@ def log2vis(msgs, settings):
 
 
 def protect_format_seq(msg):
-    '''
+    ''' 
 
     '''
 
