@@ -96,6 +96,24 @@ class CAMERA_PT_presets(bl_ui.utils.PresetPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -318,6 +336,24 @@ class SAFE_AREAS_PT_presets(bl_ui.utils.PresetPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -514,6 +550,24 @@ class DATA_PT_camera(CameraButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -709,6 +763,24 @@ class DATA_PT_camera_background_image(CameraButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -898,6 +970,24 @@ class DATA_PT_camera_display(CameraButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1090,6 +1180,24 @@ class DATA_PT_camera_display_composition_guides(
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1285,6 +1393,24 @@ class DATA_PT_camera_dof(CameraButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1474,6 +1600,24 @@ class DATA_PT_camera_dof_aperture(CameraButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1675,6 +1819,24 @@ class DATA_PT_camera_safe_areas(CameraButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1873,6 +2035,24 @@ class DATA_PT_camera_safe_areas_center_cut(CameraButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2059,6 +2239,24 @@ class DATA_PT_camera_stereoscopy(CameraButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2248,6 +2446,24 @@ class DATA_PT_context_camera(CameraButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2441,6 +2657,24 @@ class DATA_PT_custom_props_camera(CameraButtonsPanel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2626,6 +2860,24 @@ class DATA_PT_lens(CameraButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
