@@ -76,6 +76,24 @@ class RENDER_PT_context(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -285,6 +303,24 @@ class RENDER_PT_color_management(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -483,6 +519,24 @@ class RENDER_PT_color_management_curves(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -678,6 +732,24 @@ class RENDER_PT_eevee_ambient_occlusion(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -873,6 +945,24 @@ class RENDER_PT_eevee_bloom(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1062,6 +1152,24 @@ class RENDER_PT_eevee_depth_of_field(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1251,6 +1359,24 @@ class RENDER_PT_eevee_film(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1440,6 +1566,24 @@ class RENDER_PT_eevee_hair(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1629,6 +1773,24 @@ class RENDER_PT_eevee_indirect_lighting(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1818,6 +1980,24 @@ class RENDER_PT_eevee_indirect_lighting_display(
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2013,6 +2193,24 @@ class RENDER_PT_eevee_motion_blur(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2202,6 +2400,24 @@ class RENDER_PT_eevee_performance(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2388,6 +2604,24 @@ class RENDER_PT_eevee_sampling(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2583,6 +2817,24 @@ class RENDER_PT_eevee_screen_space_reflections(
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2772,6 +3024,24 @@ class RENDER_PT_eevee_shadows(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2961,6 +3231,24 @@ class RENDER_PT_eevee_subsurface_scattering(
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -3150,6 +3438,24 @@ class RENDER_PT_eevee_volumetric(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -3345,6 +3651,24 @@ class RENDER_PT_eevee_volumetric_lighting(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -3540,6 +3864,24 @@ class RENDER_PT_eevee_volumetric_shadows(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -3657,6 +3999,9 @@ class RENDER_PT_eevee_volumetric_shadows(RenderButtonsPanel, bpy_types.Panel,
 
 class RENDER_PT_gpencil(RenderButtonsPanel, bpy_types.Panel,
                         bpy_types._GenericUI):
+    COMPAT_ENGINES = None
+    ''' '''
+
     bl_context = None
     ''' '''
 
@@ -3729,6 +4074,24 @@ class RENDER_PT_gpencil(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -3915,6 +4278,24 @@ class RENDER_PT_opengl_color(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -4104,6 +4485,24 @@ class RENDER_PT_opengl_film(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -4290,6 +4689,24 @@ class RENDER_PT_opengl_lighting(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -4476,6 +4893,24 @@ class RENDER_PT_opengl_options(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -4662,6 +5097,24 @@ class RENDER_PT_opengl_sampling(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -4857,6 +5310,24 @@ class RENDER_PT_simplify(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -5056,6 +5527,24 @@ class RENDER_PT_simplify_greasepencil(
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -5245,6 +5734,24 @@ class RENDER_PT_simplify_render(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -5434,6 +5941,24 @@ class RENDER_PT_simplify_viewport(RenderButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
