@@ -93,6 +93,24 @@ class SPREADSHEET_HT_header(bpy_types.Header, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -189,6 +207,12 @@ class SPREADSHEET_HT_header(bpy_types.Header, bpy_types._GenericUI):
         '''
         pass
 
+    def selection_filter_available(self, space):
+        ''' 
+
+        '''
+        pass
+
     def type_recast(self):
         ''' 
 
