@@ -1,11 +1,13 @@
 import sys
 import typing
 
+GenericType = typing.TypeVar("GenericType")
+
 
 def aspect(fontid: int, aspect: float):
     ''' Set the aspect for drawing text.
 
-    :param fontid: blf.load , for default font use 0.
+    :param fontid: `blf.load`, for default font use 0.
     :type fontid: int
     :param aspect: The aspect ratio for text drawing to use.
     :type aspect: float
@@ -17,7 +19,7 @@ def aspect(fontid: int, aspect: float):
 def clipping(fontid: int, xmin: float, ymin: float, xmax: float, ymax: float):
     ''' Set the clipping, enable/disable using CLIPPING.
 
-    :param fontid: blf.load , for default font use 0.
+    :param fontid: `blf.load`, for default font use 0.
     :type fontid: int
     :param xmin: Clip the drawing area by these bounds.
     :type xmin: float
@@ -35,7 +37,7 @@ def clipping(fontid: int, xmin: float, ymin: float, xmax: float, ymax: float):
 def color(fontid: int, r: float, g: float, b: float, a: float):
     ''' Set the color for drawing text.
 
-    :param fontid: blf.load , for default font use 0.
+    :param fontid: `blf.load`, for default font use 0.
     :type fontid: int
     :param r: red channel 0.0 - 1.0.
     :type r: float
@@ -50,14 +52,14 @@ def color(fontid: int, r: float, g: float, b: float, a: float):
     pass
 
 
-def dimensions(fontid: int, text: str) -> tuple:
+def dimensions(fontid: int, text: str) -> typing.Tuple:
     ''' Return the width and height of the text.
 
-    :param fontid: blf.load , for default font use 0.
+    :param fontid: `blf.load`, for default font use 0.
     :type fontid: int
     :param text: the text to draw.
     :type text: str
-    :rtype: tuple
+    :rtype: typing.Tuple
     :return: the width and height of the text.
     '''
 
@@ -67,7 +69,7 @@ def dimensions(fontid: int, text: str) -> tuple:
 def disable(fontid: int, option: int):
     ''' Disable option.
 
-    :param fontid: blf.load , for default font use 0.
+    :param fontid: `blf.load`, for default font use 0.
     :type fontid: int
     :param option: One of ROTATION, CLIPPING, SHADOW or KERNING_DEFAULT.
     :type option: int
@@ -79,7 +81,7 @@ def disable(fontid: int, option: int):
 def draw(fontid: int, text: str):
     ''' Draw text in the current context.
 
-    :param fontid: blf.load , for default font use 0.
+    :param fontid: `blf.load`, for default font use 0.
     :type fontid: int
     :param text: the text to draw.
     :type text: str
@@ -91,7 +93,7 @@ def draw(fontid: int, text: str):
 def enable(fontid: int, option: int):
     ''' Enable option.
 
-    :param fontid: blf.load , for default font use 0.
+    :param fontid: `blf.load`, for default font use 0.
     :type fontid: int
     :param option: One of ROTATION, CLIPPING, SHADOW or KERNING_DEFAULT.
     :type option: int
@@ -100,11 +102,12 @@ def enable(fontid: int, option: int):
     pass
 
 
-def load(filename: str):
+def load(filename: str) -> typing.Any:
     ''' Load a new font.
 
     :param filename: the filename of the font.
     :type filename: str
+    :rtype: typing.Any
     :return: the new font's fontid or -1 if there was an error.
     '''
 
@@ -114,7 +117,7 @@ def load(filename: str):
 def position(fontid: int, x: float, y: float, z: float):
     ''' Set the position for drawing text.
 
-    :param fontid: blf.load , for default font use 0.
+    :param fontid: `blf.load`, for default font use 0.
     :type fontid: int
     :param x: X axis position to draw the text.
     :type x: float
@@ -130,7 +133,7 @@ def position(fontid: int, x: float, y: float, z: float):
 def rotation(fontid: int, angle: float):
     ''' Set the text rotation angle, enable/disable using ROTATION.
 
-    :param fontid: blf.load , for default font use 0.
+    :param fontid: `blf.load`, for default font use 0.
     :type fontid: int
     :param angle: The angle for text drawing to use.
     :type angle: float
@@ -142,7 +145,7 @@ def rotation(fontid: int, angle: float):
 def shadow(fontid: int, level: int, r: float, g: float, b: float, a: float):
     ''' Shadow options, enable/disable using SHADOW .
 
-    :param fontid: blf.load , for default font use 0.
+    :param fontid: `blf.load`, for default font use 0.
     :type fontid: int
     :param level: The blur level, can be 3, 5 or 0.
     :type level: int
@@ -162,7 +165,7 @@ def shadow(fontid: int, level: int, r: float, g: float, b: float, a: float):
 def shadow_offset(fontid: int, x: float, y: float):
     ''' Set the offset for shadow text.
 
-    :param fontid: blf.load , for default font use 0.
+    :param fontid: `blf.load`, for default font use 0.
     :type fontid: int
     :param x: Vertical shadow offset value in pixels.
     :type x: float
@@ -176,7 +179,7 @@ def shadow_offset(fontid: int, x: float, y: float):
 def size(fontid: int, size: int, dpi: int):
     ''' Set the size and dpi for drawing text.
 
-    :param fontid: blf.load , for default font use 0.
+    :param fontid: `blf.load`, for default font use 0.
     :type fontid: int
     :param size: Point size of the font.
     :type size: int
@@ -200,7 +203,7 @@ def unload(filename: str):
 def word_wrap(fontid: int, wrap_width: int):
     ''' Set the wrap width, enable/disable using WORD_WRAP.
 
-    :param fontid: blf.load , for default font use 0.
+    :param fontid: `blf.load`, for default font use 0.
     :type fontid: int
     :param wrap_width: The width (in pixels) to wrap words at.
     :type wrap_width: int
