@@ -13,13 +13,13 @@ class BMDeformVert:
         '''
         pass
 
-    def get(self, key: int, default=None):
+    def get(self, key: int, default: typing.Any = None):
         ''' Returns the deform weight matching the key or default when not found (matches pythons dictionary function of the same name).
 
         :param key: The key associated with deform weight.
         :type key: int
         :param default: Optional argument for the value to return if *key* is not found.
-        :type default: 
+        :type default: typing.Any
         '''
         pass
 
@@ -142,21 +142,21 @@ class BMEdge:
     :type: typing.Union[typing.List['BMVert'], 'BMElemSeq']
     '''
 
-    def calc_face_angle(self, fallback=None) -> float:
+    def calc_face_angle(self, fallback: typing.Any = None) -> float:
         ''' 
 
-        :param fallback: return this when the edge doesn't have 2 faces (instead of raising a :exc: ValueError ).
-        :type fallback: 
+        :param fallback: return this when the edge doesn't have 2 faces (instead of raising a :exc:`ValueError`).
+        :type fallback: typing.Any
         :rtype: float
         :return: The angle between 2 connected faces in radians.
         '''
         pass
 
-    def calc_face_angle_signed(self, fallback=None) -> float:
+    def calc_face_angle_signed(self, fallback: typing.Any = None) -> float:
         ''' 
 
-        :param fallback: return this when the edge doesn't have 2 faces (instead of raising a :exc: ValueError ).
-        :type fallback: 
+        :param fallback: return this when the edge doesn't have 2 faces (instead of raising a :exc:`ValueError`).
+        :type fallback: typing.Any
         :rtype: float
         :return: The angle between 2 connected faces in radians (negative for concave join).
         '''
@@ -227,18 +227,18 @@ class BMEdgeSeq:
     '''
 
     def ensure_lookup_table(self):
-        ''' Ensure internal data needed for int subscription is initialized with verts/edges/faces, eg bm.verts[index] . This needs to be called again after adding/removing data in this sequence.
+        ''' Ensure internal data needed for int subscription is initialized with verts/edges/faces, eg ``bm.verts[index]``. This needs to be called again after adding/removing data in this sequence.
 
         '''
         pass
 
-    def get(self, verts: 'BMVert', fallback=None) -> 'BMEdge':
+    def get(self, verts: 'BMVert', fallback: typing.Any = None) -> 'BMEdge':
         ''' Return an edge which uses the **verts** passed.
 
         :param verts: Sequence of verts.
         :type verts: 'BMVert'
         :param fallback:  Return this value if nothing is found.
-        :type fallback: 
+        :type fallback: typing.Any
         :rtype: 'BMEdge'
         :return: The edge found or None
         '''
@@ -250,14 +250,13 @@ class BMEdgeSeq:
         '''
         pass
 
-    def new(self, verts: 'BMVert',
-            example: typing.Optional['BMEdge'] = None) -> 'BMEdge':
+    def new(self, verts: 'BMVert', example: 'BMEdge' = None) -> 'BMEdge':
         ''' Create a new edge from a given pair of verts.
 
         :param verts: Vertex pair.
         :type verts: 'BMVert'
         :param example: Existing edge to initialize settings (optional argument).
-        :type example: typing.Optional['BMEdge']
+        :type example: 'BMEdge'
         :rtype: 'BMEdge'
         :return: The newly created edge.
         '''
@@ -269,13 +268,13 @@ class BMEdgeSeq:
         '''
         pass
 
-    def sort(self, key=None, reverse=False):
+    def sort(self, key: typing.Any = None, reverse: typing.Any = False):
         ''' Sort the elements of this sequence, using an optional custom sort key. Indices of elements are not changed, BMElemeSeq.index_update() can be used for that.
 
         :param key: The key that sets the ordering of the elements.
-        :type key: 
+        :type key: typing.Any
         :param reverse: Reverse the order of the elements
-        :type reverse: 
+        :type reverse: typing.Any
         '''
         pass
 
@@ -285,10 +284,10 @@ class BMEditSelIter:
 
 
 class BMEditSelSeq:
-    active: 'BMVert' = None
+    active: typing.Union['BMVert', 'BMEdge', 'BMFace'] = None
     ''' The last selected element or None (read-only).
 
-    :type: 'BMVert'
+    :type: typing.Union['BMVert', 'BMEdge', 'BMFace']
     '''
 
     def add(self, element):
@@ -323,7 +322,7 @@ class BMEditSelSeq:
 
 
 class BMElemSeq:
-    ''' General sequence type used for accessing any sequence of BMVert , BMEdge , BMFace , BMLoop . When accessed via BMesh.verts , BMesh.edges , BMesh.faces there are also functions to create/remove items.
+    ''' General sequence type used for accessing any sequence of `BMVert`, `BMEdge`, `BMFace`, `BMLoop`. When accessed via `BMesh.verts`, `BMesh.edges`, `BMesh.faces` there are also functions to create/remove items.
     '''
 
     def index_update(self):
@@ -373,10 +372,10 @@ class BMFace:
     :type: int
     '''
 
-    normal: 'mathutils.Vector' = None
+    normal: typing.Union[typing.Sequence[float], 'mathutils.Vector'] = None
     ''' The normal for this face as a 3D, wrapped vector.
 
-    :type: 'mathutils.Vector'
+    :type: typing.Union[typing.Sequence[float], 'mathutils.Vector']
     '''
 
     select: bool = None
@@ -546,18 +545,18 @@ class BMFaceSeq:
     '''
 
     def ensure_lookup_table(self):
-        ''' Ensure internal data needed for int subscription is initialized with verts/edges/faces, eg bm.verts[index] . This needs to be called again after adding/removing data in this sequence.
+        ''' Ensure internal data needed for int subscription is initialized with verts/edges/faces, eg ``bm.verts[index]``. This needs to be called again after adding/removing data in this sequence.
 
         '''
         pass
 
-    def get(self, verts: 'BMVert', fallback=None) -> 'BMFace':
+    def get(self, verts: 'BMVert', fallback: typing.Any = None) -> 'BMFace':
         ''' Return a face which uses the **verts** passed.
 
         :param verts: Sequence of verts.
         :type verts: 'BMVert'
         :param fallback:  Return this value if nothing is found.
-        :type fallback: 
+        :type fallback: typing.Any
         :rtype: 'BMFace'
         :return: The face found or None
         '''
@@ -569,14 +568,13 @@ class BMFaceSeq:
         '''
         pass
 
-    def new(self, verts: 'BMVert',
-            example: typing.Optional['BMFace'] = None) -> 'BMFace':
+    def new(self, verts: 'BMVert', example: 'BMFace' = None) -> 'BMFace':
         ''' Create a new face from a given set of verts.
 
         :param verts: Sequence of 3 or more verts.
         :type verts: 'BMVert'
         :param example: Existing face to initialize settings (optional argument).
-        :type example: typing.Optional['BMFace']
+        :type example: 'BMFace'
         :rtype: 'BMFace'
         :return: The newly created face.
         '''
@@ -588,19 +586,19 @@ class BMFaceSeq:
         '''
         pass
 
-    def sort(self, key=None, reverse=False):
+    def sort(self, key: typing.Any = None, reverse: typing.Any = False):
         ''' Sort the elements of this sequence, using an optional custom sort key. Indices of elements are not changed, BMElemeSeq.index_update() can be used for that.
 
         :param key: The key that sets the ordering of the elements.
-        :type key: 
+        :type key: typing.Any
         :param reverse: Reverse the order of the elements
-        :type reverse: 
+        :type reverse: typing.Any
         '''
         pass
 
 
 class BMIter:
-    ''' Internal BMesh type for looping over verts/faces/edges, used for iterating over BMElemSeq types.
+    ''' Internal BMesh type for looping over verts/faces/edges, used for iterating over `BMElemSeq` types.
     '''
 
     pass
@@ -617,7 +615,7 @@ class BMLayerAccessEdge:
     '''
 
     color = None
-    ''' Generic RGBA color with 8-bit precision custom-data layer. type: BMLayerCollection'''
+    ''' Generic RGBA color with 8-bit precision custom-data layer. type: `BMLayerCollection`'''
 
     crease: 'BMLayerCollection' = None
     ''' Edge crease for subdivision surface - float in [0 - 1].
@@ -626,22 +624,22 @@ class BMLayerAccessEdge:
     '''
 
     float = None
-    ''' Generic float custom-data layer. type: BMLayerCollection'''
+    ''' Generic float custom-data layer. type: `BMLayerCollection`'''
 
     float_color = None
-    ''' Generic RGBA color with float precision custom-data layer. type: BMLayerCollection'''
+    ''' Generic RGBA color with float precision custom-data layer. type: `BMLayerCollection`'''
 
     float_vector = None
-    ''' Generic 3D vector with float precision custom-data layer. type: BMLayerCollection'''
+    ''' Generic 3D vector with float precision custom-data layer. type: `BMLayerCollection`'''
 
     freestyle = None
-    ''' Accessor for Freestyle edge layer. type: BMLayerCollection'''
+    ''' Accessor for Freestyle edge layer. type: `BMLayerCollection`'''
 
     int = None
-    ''' Generic int custom-data layer. type: BMLayerCollection'''
+    ''' Generic int custom-data layer. type: `BMLayerCollection`'''
 
     string = None
-    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: BMLayerCollection'''
+    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: `BMLayerCollection`'''
 
 
 class BMLayerAccessFace:
@@ -649,28 +647,28 @@ class BMLayerAccessFace:
     '''
 
     color = None
-    ''' Generic RGBA color with 8-bit precision custom-data layer. type: BMLayerCollection'''
+    ''' Generic RGBA color with 8-bit precision custom-data layer. type: `BMLayerCollection`'''
 
     face_map = None
-    ''' FaceMap custom-data layer. type: BMLayerCollection'''
+    ''' FaceMap custom-data layer. type: `BMLayerCollection`'''
 
     float = None
-    ''' Generic float custom-data layer. type: BMLayerCollection'''
+    ''' Generic float custom-data layer. type: `BMLayerCollection`'''
 
     float_color = None
-    ''' Generic RGBA color with float precision custom-data layer. type: BMLayerCollection'''
+    ''' Generic RGBA color with float precision custom-data layer. type: `BMLayerCollection`'''
 
     float_vector = None
-    ''' Generic 3D vector with float precision custom-data layer. type: BMLayerCollection'''
+    ''' Generic 3D vector with float precision custom-data layer. type: `BMLayerCollection`'''
 
     freestyle = None
-    ''' Accessor for Freestyle face layer. type: BMLayerCollection'''
+    ''' Accessor for Freestyle face layer. type: `BMLayerCollection`'''
 
     int = None
-    ''' Generic int custom-data layer. type: BMLayerCollection'''
+    ''' Generic int custom-data layer. type: `BMLayerCollection`'''
 
     string = None
-    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: BMLayerCollection'''
+    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: `BMLayerCollection`'''
 
 
 class BMLayerAccessLoop:
@@ -678,25 +676,25 @@ class BMLayerAccessLoop:
     '''
 
     color = None
-    ''' Generic RGBA color with 8-bit precision custom-data layer. type: BMLayerCollection'''
+    ''' Generic RGBA color with 8-bit precision custom-data layer. type: `BMLayerCollection`'''
 
     float = None
-    ''' Generic float custom-data layer. type: BMLayerCollection'''
+    ''' Generic float custom-data layer. type: `BMLayerCollection`'''
 
     float_color = None
-    ''' Generic RGBA color with float precision custom-data layer. type: BMLayerCollection'''
+    ''' Generic RGBA color with float precision custom-data layer. type: `BMLayerCollection`'''
 
     float_vector = None
-    ''' Generic 3D vector with float precision custom-data layer. type: BMLayerCollection'''
+    ''' Generic 3D vector with float precision custom-data layer. type: `BMLayerCollection`'''
 
     int = None
-    ''' Generic int custom-data layer. type: BMLayerCollection'''
+    ''' Generic int custom-data layer. type: `BMLayerCollection`'''
 
     string = None
-    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: BMLayerCollection'''
+    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: `BMLayerCollection`'''
 
     uv = None
-    ''' Accessor for BMLoopUV UV (as a 2D Vector). type: BMLayerCollection'''
+    ''' Accessor for `BMLoopUV` UV (as a 2D Vector). type: `BMLayerCollection`'''
 
 
 class BMLayerAccessVert:
@@ -710,25 +708,25 @@ class BMLayerAccessVert:
     '''
 
     color = None
-    ''' Generic RGBA color with 8-bit precision custom-data layer. type: BMLayerCollection'''
+    ''' Generic RGBA color with 8-bit precision custom-data layer. type: `BMLayerCollection`'''
 
     deform = None
-    ''' Vertex deform weight BMDeformVert (TODO). type: BMLayerCollection'''
+    ''' Vertex deform weight `BMDeformVert` (TODO). type: `BMLayerCollection`'''
 
     float = None
-    ''' Generic float custom-data layer. type: BMLayerCollection'''
+    ''' Generic float custom-data layer. type: `BMLayerCollection`'''
 
     float_color = None
-    ''' Generic RGBA color with float precision custom-data layer. type: BMLayerCollection'''
+    ''' Generic RGBA color with float precision custom-data layer. type: `BMLayerCollection`'''
 
     float_vector = None
-    ''' Generic 3D vector with float precision custom-data layer. type: BMLayerCollection'''
+    ''' Generic 3D vector with float precision custom-data layer. type: `BMLayerCollection`'''
 
     int = None
-    ''' Generic int custom-data layer. type: BMLayerCollection'''
+    ''' Generic int custom-data layer. type: `BMLayerCollection`'''
 
     paint_mask = None
-    ''' Accessor for paint mask layer. type: BMLayerCollection'''
+    ''' Accessor for paint mask layer. type: `BMLayerCollection`'''
 
     shape: 'BMLayerCollection' = None
     ''' Vertex shapekey absolute location (as a 3D Vector).
@@ -737,10 +735,10 @@ class BMLayerAccessVert:
     '''
 
     skin = None
-    ''' Accessor for skin layer. type: BMLayerCollection'''
+    ''' Accessor for skin layer. type: `BMLayerCollection`'''
 
     string = None
-    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: BMLayerCollection'''
+    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: `BMLayerCollection`'''
 
 
 class BMLayerCollection:
@@ -759,13 +757,13 @@ class BMLayerCollection:
     :type: bool
     '''
 
-    def get(self, key: str, default=None):
+    def get(self, key: str, default: typing.Any = None):
         ''' Returns the value of the layer matching the key or default when not found (matches pythons dictionary function of the same name).
 
         :param key: The key associated with the layer.
         :type key: str
         :param default: Optional argument for the value to return if *key* is not found.
-        :type default: 
+        :type default: typing.Any
         '''
         pass
 
@@ -830,19 +828,19 @@ class BMLayerItem:
     :type: str
     '''
 
-    def copy_from(self, other):
+    def copy_from(self, other: typing.Any):
         ''' Return a copy of the layer
 
         :param other:  Another layer to copy from.
-        :type other: 
-        :param other:  BMLayerItem
-        :type other: 
+        :type other: typing.Any
+        :param other:  `BMLayerItem`
+        :type other: typing.Any
         '''
         pass
 
 
 class BMLoop:
-    ''' This is normally accessed from BMFace.loops where each face loop represents a corner of the face.
+    ''' This is normally accessed from `BMFace.loops` where each face loop represents a corner of the face.
     '''
 
     edge: 'BMEdge' = None
@@ -949,16 +947,16 @@ class BMLoop:
 
     def copy_from_face_interp(self,
                               face: 'BMFace',
-                              vert: typing.Optional[bool] = True,
-                              multires: typing.Optional[bool] = True):
+                              vert: bool = True,
+                              multires: bool = True):
         ''' Interpolate the customdata from a face onto this loop (the loops vert should overlap the face).
 
         :param face: The face to interpolate data from.
         :type face: 'BMFace'
         :param vert: When enabled, interpolate the loops vertex data (optional).
-        :type vert: typing.Optional[bool]
+        :type vert: bool
         :param multires: When enabled, interpolate the loops multires data (optional).
-        :type multires: typing.Optional[bool]
+        :type multires: bool
         '''
         pass
 
@@ -984,10 +982,10 @@ class BMLoopUV:
     :type: bool
     '''
 
-    uv: 'mathutils.Vector' = None
+    uv: typing.Union[typing.Sequence[float], 'mathutils.Vector'] = None
     ''' Loops UV (as a 2D Vector).
 
-    :type: 'mathutils.Vector'
+    :type: typing.Union[typing.Sequence[float], 'mathutils.Vector']
     '''
 
 
@@ -995,10 +993,10 @@ class BMVert:
     ''' The BMesh vertex type
     '''
 
-    co: 'mathutils.Vector' = None
+    co: typing.Union[typing.Sequence[float], 'mathutils.Vector'] = None
     ''' The coordinates for this vertex as a 3D, wrapped vector.
 
-    :type: 'mathutils.Vector'
+    :type: typing.Union[typing.Sequence[float], 'mathutils.Vector']
     '''
 
     hide: bool = None
@@ -1055,10 +1053,10 @@ class BMVert:
     :type: typing.Union[typing.List['BMLoop'], 'BMElemSeq']
     '''
 
-    normal: 'mathutils.Vector' = None
+    normal: typing.Union[typing.Sequence[float], 'mathutils.Vector'] = None
     ''' The normal for this vertex as a 3D, wrapped vector.
 
-    :type: 'mathutils.Vector'
+    :type: typing.Union[typing.Sequence[float], 'mathutils.Vector']
     '''
 
     select: bool = None
@@ -1073,11 +1071,11 @@ class BMVert:
     :type: bool
     '''
 
-    def calc_edge_angle(self, fallback=None) -> float:
+    def calc_edge_angle(self, fallback: typing.Any = None) -> float:
         ''' Return the angle between this vert's two connected edges.
 
-        :param fallback: return this when the vert doesn't have 2 edges (instead of raising a :exc: ValueError ).
-        :type fallback: 
+        :param fallback: return this when the vert doesn't have 2 edges (instead of raising a :exc:`ValueError`).
+        :type fallback: typing.Any
         :rtype: float
         :return: Angle between edges in radians.
         '''
@@ -1144,7 +1142,7 @@ class BMVertSeq:
     '''
 
     def ensure_lookup_table(self):
-        ''' Ensure internal data needed for int subscription is initialized with verts/edges/faces, eg bm.verts[index] . This needs to be called again after adding/removing data in this sequence.
+        ''' Ensure internal data needed for int subscription is initialized with verts/edges/faces, eg ``bm.verts[index]``. This needs to be called again after adding/removing data in this sequence.
 
         '''
         pass
@@ -1156,12 +1154,13 @@ class BMVertSeq:
         pass
 
     def new(self,
-            co: typing.Optional[typing.Tuple[float]] = (0.0, 0.0, 0.0),
+            co: typing.Union[typing.Sequence[float], 'mathutils.Vector'] = (
+                0.0, 0.0, 0.0),
             example: 'BMVert' = None) -> 'BMVert':
         ''' Create a new vertex.
 
         :param co: The initial location of the vertex (optional argument).
-        :type co: typing.Optional[typing.Tuple[float]]
+        :type co: typing.Union[typing.Sequence[float], 'mathutils.Vector']
         :param example: Existing vert to initialize settings.
         :type example: 'BMVert'
         :rtype: 'BMVert'
@@ -1175,13 +1174,13 @@ class BMVertSeq:
         '''
         pass
 
-    def sort(self, key=None, reverse=False):
+    def sort(self, key: typing.Any = None, reverse: typing.Any = False):
         ''' Sort the elements of this sequence, using an optional custom sort key. Indices of elements are not changed, BMElemeSeq.index_update() can be used for that.
 
         :param key: The key that sets the ordering of the elements.
-        :type key: 
+        :type key: typing.Any
         :param reverse: Reverse the order of the elements
-        :type reverse: 
+        :type reverse: typing.Any
         '''
         pass
 
@@ -1190,16 +1189,16 @@ class BMesh:
     ''' The BMesh data structure
     '''
 
-    edges: typing.Union[typing.List['BMEdg'], 'BMEdgeSeq'] = None
+    edges: 'BMEdgeSeq' = None
     ''' This meshes edge sequence (read-only).
 
-    :type: typing.Union[typing.List['BMEdg'], 'BMEdgeSeq']
+    :type: 'BMEdgeSeq'
     '''
 
-    faces: typing.Union[typing.List['BMFac'], 'BMFaceSeq'] = None
+    faces: 'BMFaceSeq' = None
     ''' This meshes face sequence (read-only).
 
-    :type: typing.Union[typing.List['BMFac'], 'BMFaceSeq']
+    :type: 'BMFaceSeq'
     '''
 
     is_valid: bool = None
@@ -1214,17 +1213,16 @@ class BMesh:
     :type: bool
     '''
 
-    loops: typing.Union[typing.List['BMLoop'], 'BMLoopSeq'] = None
+    loops: 'BMLoopSeq' = None
     ''' This meshes loops (read-only).
 
-    :type: typing.Union[typing.List['BMLoop'], 'BMLoopSeq']
+    :type: 'BMLoopSeq'
     '''
 
-    select_history: typing.Union[typing.
-                                 List['BMEditSel'], 'BMEditSelSeq'] = None
+    select_history: 'BMEditSelSeq' = None
     ''' Sequence of selected items (the last is displayed as active).
 
-    :type: typing.Union[typing.List['BMEditSel'], 'BMEditSelSeq']
+    :type: 'BMEditSelSeq'
     '''
 
     select_mode: typing.Set = None
@@ -1233,16 +1231,16 @@ class BMesh:
     :type: typing.Set
     '''
 
-    verts: typing.Union[typing.List['BMVert'], 'BMVertSeq'] = None
+    verts: 'BMVertSeq' = None
     ''' This meshes vert sequence (read-only).
 
-    :type: typing.Union[typing.List['BMVert'], 'BMVertSeq']
+    :type: 'BMVertSeq'
     '''
 
-    def calc_loop_triangles(self) -> 'BMLoop':
+    def calc_loop_triangles(self) -> typing.List['BMLoop']:
         ''' Calculate triangle tessellation from quads/ngons.
 
-        :rtype: 'BMLoop'
+        :rtype: typing.List['BMLoop']
         :return: The triangulated faces.
         '''
         pass
@@ -1324,7 +1322,7 @@ class BMesh:
         pass
 
     def select_flush_mode(self):
-        ''' flush selection based on the current mode current BMesh.select_mode .
+        ''' flush selection based on the current mode current `BMesh.select_mode`.
 
         '''
         pass
