@@ -164,24 +164,6 @@ def channels_fcurves_enable(override_context: typing.
     pass
 
 
-def channels_find(override_context: typing.
-                  Union[typing.Dict, 'bpy.types.Context'] = None,
-                  execution_context: typing.Union[str, int] = None,
-                  undo: typing.Optional[bool] = None,
-                  *,
-                  query: typing.Union[str, typing.Any] = "Query"):
-    ''' Filter the set of channels shown to only include those with matching names
-
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    :param query: Text to search for in channel names
-    :type query: typing.Union[str, typing.Any]
-    '''
-
-    pass
-
-
 def channels_group(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
@@ -243,7 +225,7 @@ def channels_select_all(override_context: typing.
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: typing.Optional[bool]
-    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle, Toggle selection for all elements. * ``SELECT`` Select, Select all elements. * ``DESELECT`` Deselect, Deselect all elements. * ``INVERT`` Invert, Invert selection of all elements.
+    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle -- Toggle selection for all elements. * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements. * ``INVERT`` Invert -- Invert selection of all elements.
     :type action: typing.Optional[typing.Any]
     '''
 
@@ -286,6 +268,20 @@ def channels_select_box(override_context: typing.
     pass
 
 
+def channels_select_filter(override_context: typing.
+                           Union[typing.Dict, 'bpy.types.Context'] = None,
+                           execution_context: typing.Union[str, int] = None,
+                           undo: typing.Optional[bool] = None):
+    ''' Start entering text which filters the set of channels shown to only include those with matching names
+
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    '''
+
+    pass
+
+
 def channels_setting_disable(override_context: typing.
                              Union[typing.Dict, 'bpy.types.Context'] = None,
                              execution_context: typing.Union[str, int] = None,
@@ -492,8 +488,7 @@ def keyframe_delete(override_context: typing.
                     execution_context: typing.Union[str, int] = None,
                     undo: typing.Optional[bool] = None,
                     *,
-                    type: typing.Union[str, int, typing.Any] = 'DEFAULT',
-                    confirm_success: typing.Union[bool, typing.Any] = True):
+                    type: typing.Union[str, int, typing.Any] = 'DEFAULT'):
     ''' Delete keyframes on the current frame for all properties in the specified Keying Set
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
@@ -501,8 +496,6 @@ def keyframe_delete(override_context: typing.
     :type undo: typing.Optional[bool]
     :param type: Keying Set, The Keying Set to use
     :type type: typing.Union[str, int, typing.Any]
-    :param confirm_success: Confirm Successful Delete, Show a popup when the keyframes get successfully removed
-    :type confirm_success: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -526,22 +519,18 @@ def keyframe_delete_button(override_context: typing.
     pass
 
 
-def keyframe_delete_by_name(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
-        *,
-        type: typing.Union[str, typing.Any] = "Type",
-        confirm_success: typing.Union[bool, typing.Any] = True):
+def keyframe_delete_by_name(override_context: typing.
+                            Union[typing.Dict, 'bpy.types.Context'] = None,
+                            execution_context: typing.Union[str, int] = None,
+                            undo: typing.Optional[bool] = None,
+                            *,
+                            type: typing.Union[str, typing.Any] = "Type"):
     ''' Alternate access to 'Delete Keyframe' for keymaps to use
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: typing.Optional[bool]
     :type type: typing.Union[str, typing.Any]
-    :param confirm_success: Confirm Successful Delete, Show a popup when the keyframes get successfully removed
-    :type confirm_success: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -566,8 +555,7 @@ def keyframe_insert(override_context: typing.
                     execution_context: typing.Union[str, int] = None,
                     undo: typing.Optional[bool] = None,
                     *,
-                    type: typing.Union[str, int, typing.Any] = 'DEFAULT',
-                    confirm_success: typing.Union[bool, typing.Any] = True):
+                    type: typing.Union[str, int, typing.Any] = 'DEFAULT'):
     ''' Insert keyframes on the current frame for all properties in the specified Keying Set
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
@@ -575,8 +563,6 @@ def keyframe_insert(override_context: typing.
     :type undo: typing.Optional[bool]
     :param type: Keying Set, The Keying Set to use
     :type type: typing.Union[str, int, typing.Any]
-    :param confirm_success: Confirm Successful Insert, Show a popup when the keyframes get successfully added
-    :type confirm_success: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -600,22 +586,18 @@ def keyframe_insert_button(override_context: typing.
     pass
 
 
-def keyframe_insert_by_name(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
-        *,
-        type: typing.Union[str, typing.Any] = "Type",
-        confirm_success: typing.Union[bool, typing.Any] = True):
+def keyframe_insert_by_name(override_context: typing.
+                            Union[typing.Dict, 'bpy.types.Context'] = None,
+                            execution_context: typing.Union[str, int] = None,
+                            undo: typing.Optional[bool] = None,
+                            *,
+                            type: typing.Union[str, typing.Any] = "Type"):
     ''' Alternate access to 'Insert Keyframe' for keymaps to use
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: typing.Optional[bool]
     :type type: typing.Union[str, typing.Any]
-    :param confirm_success: Confirm Successful Insert, Show a popup when the keyframes get successfully added
-    :type confirm_success: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -628,7 +610,6 @@ def keyframe_insert_menu(
         undo: typing.Optional[bool] = None,
         *,
         type: typing.Union[str, int, typing.Any] = 'DEFAULT',
-        confirm_success: typing.Union[bool, typing.Any] = False,
         always_prompt: typing.Union[bool, typing.Any] = False):
     ''' Insert Keyframes for specified Keying Set, with menu of available Keying Sets if undefined
 
@@ -637,8 +618,6 @@ def keyframe_insert_menu(
     :type undo: typing.Optional[bool]
     :param type: Keying Set, The Keying Set to use
     :type type: typing.Union[str, int, typing.Any]
-    :param confirm_success: Confirm Successful Insert, Show a popup when the keyframes get successfully added
-    :type confirm_success: typing.Union[bool, typing.Any]
     :param always_prompt: Always Show Menu
     :type always_prompt: typing.Union[bool, typing.Any]
     '''
