@@ -8,16 +8,16 @@ GenericType = typing.TypeVar("GenericType")
 def rule_add(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
-             undo: bool = None,
+             undo: typing.Optional[bool] = None,
              *,
-             type: typing.Union[str, int] = 'GOAL'):
+             type: typing.Optional[typing.Any] = 'GOAL'):
     ''' Add a boid rule to the current boid state
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
-    :param type: Type * GOAL Goal -- Go to assigned object or loudest assigned signal source. * AVOID Avoid -- Get away from assigned object or loudest assigned signal source. * AVOID_COLLISION Avoid Collision -- Maneuver to avoid collisions with other boids and deflector objects in near future. * SEPARATE Separate -- Keep from going through other boids. * FLOCK Flock -- Move to center of neighbors and match their velocity. * FOLLOW_LEADER Follow Leader -- Follow a boid or assigned object. * AVERAGE_SPEED Average Speed -- Maintain speed, flight level or wander. * FIGHT Fight -- Go to closest enemy and attack when in range.
-    :type type: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    :param type: Type * ``GOAL`` Goal -- Go to assigned object or loudest assigned signal source. * ``AVOID`` Avoid -- Get away from assigned object or loudest assigned signal source. * ``AVOID_COLLISION`` Avoid Collision -- Maneuver to avoid collisions with other boids and deflector objects in near future. * ``SEPARATE`` Separate -- Keep from going through other boids. * ``FLOCK`` Flock -- Move to center of neighbors and match their velocity. * ``FOLLOW_LEADER`` Follow Leader -- Follow a boid or assigned object. * ``AVERAGE_SPEED`` Average Speed -- Maintain speed, flight level or wander. * ``FIGHT`` Fight -- Go to closest enemy and attack when in range.
+    :type type: typing.Optional[typing.Any]
     '''
 
     pass
@@ -26,12 +26,12 @@ def rule_add(override_context: typing.Union[typing.
 def rule_del(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
-             undo: bool = None):
+             undo: typing.Optional[bool] = None):
     ''' Delete current boid rule
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -40,12 +40,12 @@ def rule_del(override_context: typing.Union[typing.
 def rule_move_down(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None):
+                   undo: typing.Optional[bool] = None):
     ''' Move boid rule down in the list
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -54,12 +54,12 @@ def rule_move_down(override_context: typing.
 def rule_move_up(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None):
+                 undo: typing.Optional[bool] = None):
     ''' Move boid rule up in the list
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -68,12 +68,12 @@ def rule_move_up(override_context: typing.
 def state_add(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None):
+              undo: typing.Optional[bool] = None):
     ''' Add a boid state to the particle system
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -82,12 +82,12 @@ def state_add(override_context: typing.Union[typing.
 def state_del(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None):
+              undo: typing.Optional[bool] = None):
     ''' Delete current boid state
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -96,12 +96,12 @@ def state_del(override_context: typing.Union[typing.
 def state_move_down(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None):
+                    undo: typing.Optional[bool] = None):
     ''' Move boid state down in the list
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -110,12 +110,12 @@ def state_move_down(override_context: typing.
 def state_move_up(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None):
+                  undo: typing.Optional[bool] = None):
     ''' Move boid state up in the list
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
