@@ -8,16 +8,16 @@ GenericType = typing.TypeVar("GenericType")
 def action_pushdown(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None,
+                    undo: typing.Optional[bool] = None,
                     *,
-                    channel_index: int = -1):
+                    channel_index: typing.Optional[typing.Any] = -1):
     ''' Push action down onto the top of the NLA stack as a new strip
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param channel_index: Channel Index, Index of NLA action channel to perform pushdown operation on
-    :type channel_index: int
+    :type channel_index: typing.Optional[typing.Any]
     '''
 
     pass
@@ -26,16 +26,16 @@ def action_pushdown(override_context: typing.
 def action_sync_length(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
-                       undo: bool = None,
+                       undo: typing.Optional[bool] = None,
                        *,
-                       active: bool = True):
+                       active: typing.Union[bool, typing.Any] = True):
     ''' Synchronize the length of the referenced Action with the length used in the strip
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param active: Active Strip Only, Only sync the active length for the active strip
-    :type active: bool
+    :type active: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -44,16 +44,16 @@ def action_sync_length(override_context: typing.
 def action_unlink(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  force_delete: bool = False):
+                  force_delete: typing.Union[bool, typing.Any] = False):
     ''' Unlink this action from the active action slot (and/or exit Tweak Mode)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param force_delete: Force Delete, Clear Fake User and remove copy stashed in this data-block's NLA stack
-    :type force_delete: bool
+    :type force_delete: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -62,16 +62,16 @@ def action_unlink(override_context: typing.
 def actionclip_add(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   action: typing.Union[str, int] = ''):
+                   action: typing.Union[str, int, typing.Any] = ''):
     ''' Add an Action-Clip strip (i.e. an NLA Strip referencing an Action) to the active track
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param action: Action
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[str, int, typing.Any]
     '''
 
     pass
@@ -80,58 +80,57 @@ def actionclip_add(override_context: typing.
 def apply_scale(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None):
+                undo: typing.Optional[bool] = None):
     ''' Apply scaling of selected strips to their referenced Actions
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
 
 
-def bake(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        frame_start: int = 1,
-        frame_end: int = 250,
-        step: int = 1,
-        only_selected: bool = True,
-        visual_keying: bool = False,
-        clear_constraints: bool = False,
-        clear_parents: bool = False,
-        use_current_action: bool = False,
-        clean_curves: bool = False,
-        bake_types: typing.Union[typing.Set[str], typing.Set[int]] = {'POSE'}):
+def bake(override_context: typing.Union[typing.
+                                        Dict, 'bpy.types.Context'] = None,
+         execution_context: typing.Union[str, int] = None,
+         undo: typing.Optional[bool] = None,
+         *,
+         frame_start: typing.Optional[typing.Any] = 1,
+         frame_end: typing.Optional[typing.Any] = 250,
+         step: typing.Optional[typing.Any] = 1,
+         only_selected: typing.Union[bool, typing.Any] = True,
+         visual_keying: typing.Union[bool, typing.Any] = False,
+         clear_constraints: typing.Union[bool, typing.Any] = False,
+         clear_parents: typing.Union[bool, typing.Any] = False,
+         use_current_action: typing.Union[bool, typing.Any] = False,
+         clean_curves: typing.Union[bool, typing.Any] = False,
+         bake_types: typing.Optional[typing.Any] = {'POSE'}):
     ''' Bake all selected objects location/scale/rotation animation to an action
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param frame_start: Start Frame, Start frame for baking
-    :type frame_start: int
+    :type frame_start: typing.Optional[typing.Any]
     :param frame_end: End Frame, End frame for baking
-    :type frame_end: int
+    :type frame_end: typing.Optional[typing.Any]
     :param step: Frame Step, Frame Step
-    :type step: int
+    :type step: typing.Optional[typing.Any]
     :param only_selected: Only Selected Bones, Only key selected bones (Pose baking only)
-    :type only_selected: bool
+    :type only_selected: typing.Union[bool, typing.Any]
     :param visual_keying: Visual Keying, Keyframe from the final transformations (with constraints applied)
-    :type visual_keying: bool
+    :type visual_keying: typing.Union[bool, typing.Any]
     :param clear_constraints: Clear Constraints, Remove all constraints from keyed object/bones, and do 'visual' keying
-    :type clear_constraints: bool
+    :type clear_constraints: typing.Union[bool, typing.Any]
     :param clear_parents: Clear Parents, Bake animation onto the object then clear parents (objects only)
-    :type clear_parents: bool
+    :type clear_parents: typing.Union[bool, typing.Any]
     :param use_current_action: Overwrite Current Action, Bake animation into current action, instead of creating a new one (useful for baking only part of bones in an armature)
-    :type use_current_action: bool
+    :type use_current_action: typing.Union[bool, typing.Any]
     :param clean_curves: Clean Curves, After baking curves, remove redundant keys
-    :type clean_curves: bool
-    :param bake_types: Bake Data, Which data's transformations to bake * POSE Pose -- Bake bones transformations. * OBJECT Object -- Bake object transformations.
-    :type bake_types: typing.Union[typing.Set[str], typing.Set[int]]
+    :type clean_curves: typing.Union[bool, typing.Any]
+    :param bake_types: Bake Data, Which data's transformations to bake * ``POSE`` Pose -- Bake bones transformations. * ``OBJECT`` Object -- Bake object transformations.
+    :type bake_types: typing.Optional[typing.Any]
     '''
 
     pass
@@ -140,16 +139,16 @@ def bake(
 def channels_click(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   extend: bool = False):
+                   extend: typing.Union[bool, typing.Any] = False):
     ''' Handle clicks to select NLA channels
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param extend: Extend Select
-    :type extend: bool
+    :type extend: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -158,42 +157,43 @@ def channels_click(override_context: typing.
 def clear_scale(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None):
+                undo: typing.Optional[bool] = None):
     ''' Reset scaling of selected strips
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
 
 
-def click_select(override_context: typing.
-                 Union[typing.Dict, 'bpy.types.Context'] = None,
-                 execution_context: typing.Union[str, int] = None,
-                 undo: bool = None,
-                 *,
-                 wait_to_deselect_others: bool = False,
-                 mouse_x: int = 0,
-                 mouse_y: int = 0,
-                 extend: bool = False,
-                 deselect_all: bool = False):
+def click_select(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: typing.Optional[bool] = None,
+        *,
+        wait_to_deselect_others: typing.Union[bool, typing.Any] = False,
+        mouse_x: typing.Optional[typing.Any] = 0,
+        mouse_y: typing.Optional[typing.Any] = 0,
+        extend: typing.Union[bool, typing.Any] = False,
+        deselect_all: typing.Union[bool, typing.Any] = False):
     ''' Handle clicks to select NLA Strips
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param wait_to_deselect_others: Wait to Deselect Others
-    :type wait_to_deselect_others: bool
+    :type wait_to_deselect_others: typing.Union[bool, typing.Any]
     :param mouse_x: Mouse X
-    :type mouse_x: int
+    :type mouse_x: typing.Optional[typing.Any]
     :param mouse_y: Mouse Y
-    :type mouse_y: int
+    :type mouse_y: typing.Optional[typing.Any]
     :param extend: Extend Select
-    :type extend: bool
+    :type extend: typing.Union[bool, typing.Any]
     :param deselect_all: Deselect On Nothing, Deselect all when nothing under the cursor
-    :type deselect_all: bool
+    :type deselect_all: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -202,12 +202,12 @@ def click_select(override_context: typing.
 def delete(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None):
+           undo: typing.Optional[bool] = None):
     ''' Delete selected strips
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -216,19 +216,19 @@ def delete(override_context: typing.Union[typing.
 def duplicate(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None,
+              undo: typing.Optional[bool] = None,
               *,
-              linked: bool = False,
-              mode: typing.Union[str, int] = 'TRANSLATION'):
+              linked: typing.Union[bool, typing.Any] = False,
+              mode: typing.Optional[typing.Any] = 'TRANSLATION'):
     ''' Duplicate selected NLA-Strips, adding the new strips in new tracks above the originals
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param linked: Linked, When duplicating strips, assign new copies of the actions they use
-    :type linked: bool
+    :type linked: typing.Union[bool, typing.Any]
     :param mode: Mode
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Optional[typing.Any]
     '''
 
     pass
@@ -237,19 +237,19 @@ def duplicate(override_context: typing.Union[typing.
 def fmodifier_add(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  type: typing.Union[str, int] = 'NULL',
-                  only_active: bool = True):
+                  type: typing.Optional[typing.Any] = 'NULL',
+                  only_active: typing.Union[bool, typing.Any] = True):
     ''' Add F-Modifier to the active/selected NLA-Strips
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
-    :param type: Type * NULL Invalid. * GENERATOR Generator -- Generate a curve using a factorized or expanded polynomial. * FNGENERATOR Built-In Function -- Generate a curve using standard math functions such as sin and cos. * ENVELOPE Envelope -- Reshape F-Curve values, e.g. change amplitude of movements. * CYCLES Cycles -- Cyclic extend/repeat keyframe sequence. * NOISE Noise -- Add pseudo-random noise on top of F-Curves. * LIMITS Limits -- Restrict maximum and minimum values of F-Curve. * STEPPED Stepped Interpolation -- Snap values to nearest grid step, e.g. for a stop-motion look.
-    :type type: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    :param type: Type * ``NULL`` Invalid. * ``GENERATOR`` Generator -- Generate a curve using a factorized or expanded polynomial. * ``FNGENERATOR`` Built-In Function -- Generate a curve using standard math functions such as sin and cos. * ``ENVELOPE`` Envelope -- Reshape F-Curve values, e.g. change amplitude of movements. * ``CYCLES`` Cycles -- Cyclic extend/repeat keyframe sequence. * ``NOISE`` Noise -- Add pseudo-random noise on top of F-Curves. * ``LIMITS`` Limits -- Restrict maximum and minimum values of F-Curve. * ``STEPPED`` Stepped Interpolation -- Snap values to nearest grid step, e.g. for a stop-motion look.
+    :type type: typing.Optional[typing.Any]
     :param only_active: Only Active, Only add a F-Modifier of the specified type to the active strip
-    :type only_active: bool
+    :type only_active: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -258,12 +258,12 @@ def fmodifier_add(override_context: typing.
 def fmodifier_copy(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None):
+                   undo: typing.Optional[bool] = None):
     ''' Copy the F-Modifier(s) of the active NLA-Strip
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -272,19 +272,19 @@ def fmodifier_copy(override_context: typing.
 def fmodifier_paste(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None,
+                    undo: typing.Optional[bool] = None,
                     *,
-                    only_active: bool = True,
-                    replace: bool = False):
+                    only_active: typing.Union[bool, typing.Any] = True,
+                    replace: typing.Union[bool, typing.Any] = False):
     ''' Add copied F-Modifiers to the selected NLA-Strips
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param only_active: Only Active, Only paste F-Modifiers on active strip
-    :type only_active: bool
+    :type only_active: typing.Union[bool, typing.Any]
     :param replace: Replace Existing, Replace existing F-Modifiers, instead of just appending to the end of the existing list
-    :type replace: bool
+    :type replace: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -293,12 +293,12 @@ def fmodifier_paste(override_context: typing.
 def make_single_user(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
+                     undo: typing.Optional[bool] = None):
     ''' Ensure that each action is only used once in the set of strips selected
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -307,12 +307,12 @@ def make_single_user(override_context: typing.
 def meta_add(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
-             undo: bool = None):
+             undo: typing.Optional[bool] = None):
     ''' Add new meta-strips incorporating the selected strips
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -321,12 +321,12 @@ def meta_add(override_context: typing.Union[typing.
 def meta_remove(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None):
+                undo: typing.Optional[bool] = None):
     ''' Separate out the strips held by the selected meta-strips
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -335,12 +335,12 @@ def meta_remove(override_context: typing.
 def move_down(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None):
+              undo: typing.Optional[bool] = None):
     ''' Move selected strips down a track if there's room
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -349,12 +349,12 @@ def move_down(override_context: typing.Union[typing.
 def move_up(override_context: typing.Union[typing.
                                            Dict, 'bpy.types.Context'] = None,
             execution_context: typing.Union[str, int] = None,
-            undo: bool = None):
+            undo: typing.Optional[bool] = None):
     ''' Move selected strips up a track if there's room
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -363,12 +363,12 @@ def move_up(override_context: typing.Union[typing.
 def mute_toggle(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None):
+                undo: typing.Optional[bool] = None):
     ''' Mute or un-mute selected strips
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -377,12 +377,12 @@ def mute_toggle(override_context: typing.
 def previewrange_set(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
+                     undo: typing.Optional[bool] = None):
     ''' Set Preview Range based on extends of selected strips
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -391,16 +391,16 @@ def previewrange_set(override_context: typing.
 def select_all(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               action: typing.Union[str, int] = 'TOGGLE'):
+               action: typing.Optional[typing.Any] = 'TOGGLE'):
     ''' Select or deselect all NLA-Strips
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
-    :param action: Action, Selection action to execute * TOGGLE Toggle -- Toggle selection for all elements. * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements. * INVERT Invert -- Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle -- Toggle selection for all elements. * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements. * ``INVERT`` Invert -- Invert selection of all elements.
+    :type action: typing.Optional[typing.Any]
     '''
 
     pass
@@ -409,37 +409,37 @@ def select_all(override_context: typing.
 def select_box(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               axis_range: bool = False,
-               tweak: bool = False,
-               xmin: int = 0,
-               xmax: int = 0,
-               ymin: int = 0,
-               ymax: int = 0,
-               wait_for_input: bool = True,
-               mode: typing.Union[str, int] = 'SET'):
+               axis_range: typing.Union[bool, typing.Any] = False,
+               tweak: typing.Union[bool, typing.Any] = False,
+               xmin: typing.Optional[typing.Any] = 0,
+               xmax: typing.Optional[typing.Any] = 0,
+               ymin: typing.Optional[typing.Any] = 0,
+               ymax: typing.Optional[typing.Any] = 0,
+               wait_for_input: typing.Union[bool, typing.Any] = True,
+               mode: typing.Optional[typing.Any] = 'SET'):
     ''' Use box selection to grab NLA-Strips
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param axis_range: Axis Range
-    :type axis_range: bool
+    :type axis_range: typing.Union[bool, typing.Any]
     :param tweak: Tweak, Operator has been activated using a tweak event
-    :type tweak: bool
+    :type tweak: typing.Union[bool, typing.Any]
     :param xmin: X Min
-    :type xmin: int
+    :type xmin: typing.Optional[typing.Any]
     :param xmax: X Max
-    :type xmax: int
+    :type xmax: typing.Optional[typing.Any]
     :param ymin: Y Min
-    :type ymin: int
+    :type ymin: typing.Optional[typing.Any]
     :param ymax: Y Max
-    :type ymax: int
+    :type ymax: typing.Optional[typing.Any]
     :param wait_for_input: Wait for Input
-    :type wait_for_input: bool
-    :param mode: Mode * SET Set -- Set a new selection. * ADD Extend -- Extend existing selection. * SUB Subtract -- Subtract existing selection.
-    :type mode: typing.Union[str, int]
+    :type wait_for_input: typing.Union[bool, typing.Any]
+    :param mode: Mode * ``SET`` Set -- Set a new selection. * ``ADD`` Extend -- Extend existing selection. * ``SUB`` Subtract -- Subtract existing selection.
+    :type mode: typing.Optional[typing.Any]
     '''
 
     pass
@@ -448,19 +448,19 @@ def select_box(override_context: typing.
 def select_leftright(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None,
+                     undo: typing.Optional[bool] = None,
                      *,
-                     mode: typing.Union[str, int] = 'CHECK',
-                     extend: bool = False):
+                     mode: typing.Optional[typing.Any] = 'CHECK',
+                     extend: typing.Union[bool, typing.Any] = False):
     ''' Select strips to the left or the right of the current frame
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param mode: Mode
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Optional[typing.Any]
     :param extend: Extend Select
-    :type extend: bool
+    :type extend: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -469,12 +469,12 @@ def select_leftright(override_context: typing.
 def selected_objects_add(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: bool = None):
+                         undo: typing.Optional[bool] = None):
     ''' Make selected objects appear in NLA Editor by adding Animation Data
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -483,16 +483,16 @@ def selected_objects_add(override_context: typing.
 def snap(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: bool = None,
+         undo: typing.Optional[bool] = None,
          *,
-         type: typing.Union[str, int] = 'CFRA'):
+         type: typing.Optional[typing.Any] = 'CFRA'):
     ''' Move start of strips to specified time
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Optional[typing.Any]
     '''
 
     pass
@@ -501,12 +501,12 @@ def snap(override_context: typing.Union[typing.
 def soundclip_add(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None):
+                  undo: typing.Optional[bool] = None):
     ''' Add a strip for controlling when speaker plays its sound clip
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -515,12 +515,12 @@ def soundclip_add(override_context: typing.
 def split(override_context: typing.Union[typing.
                                          Dict, 'bpy.types.Context'] = None,
           execution_context: typing.Union[str, int] = None,
-          undo: bool = None):
+          undo: typing.Optional[bool] = None):
     ''' Split selected strips at their midpoints
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -529,12 +529,12 @@ def split(override_context: typing.Union[typing.
 def swap(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: bool = None):
+         undo: typing.Optional[bool] = None):
     ''' Swap order of selected strips within tracks
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -543,16 +543,16 @@ def swap(override_context: typing.Union[typing.
 def tracks_add(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               above_selected: bool = False):
+               above_selected: typing.Union[bool, typing.Any] = False):
     ''' Add NLA-Tracks above/after the selected tracks
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param above_selected: Above Selected, Add a new NLA Track above every existing selected one
-    :type above_selected: bool
+    :type above_selected: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -561,12 +561,12 @@ def tracks_add(override_context: typing.
 def tracks_delete(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None):
+                  undo: typing.Optional[bool] = None):
     ''' Delete selected NLA-Tracks and the strips they contain
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -575,12 +575,12 @@ def tracks_delete(override_context: typing.
 def transition_add(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None):
+                   undo: typing.Optional[bool] = None):
     ''' Add a transition strip between two adjacent selected strips
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -589,16 +589,16 @@ def transition_add(override_context: typing.
 def tweakmode_enter(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None,
+                    undo: typing.Optional[bool] = None,
                     *,
-                    isolate_action: bool = False):
+                    isolate_action: typing.Union[bool, typing.Any] = False):
     ''' Enter tweaking mode for the action referenced by the active strip to edit its keyframes
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param isolate_action: Isolate Action, Enable 'solo' on the NLA Track containing the active strip, to edit it without seeing the effects of the NLA stack
-    :type isolate_action: bool
+    :type isolate_action: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -607,16 +607,16 @@ def tweakmode_enter(override_context: typing.
 def tweakmode_exit(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   isolate_action: bool = False):
+                   isolate_action: typing.Union[bool, typing.Any] = False):
     ''' Exit tweaking mode for the action referenced by the active strip
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param isolate_action: Isolate Action, Disable 'solo' on any of the NLA Tracks after exiting tweak mode to get things back to normal
-    :type isolate_action: bool
+    :type isolate_action: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -625,12 +625,12 @@ def tweakmode_exit(override_context: typing.
 def view_all(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
-             undo: bool = None):
+             undo: typing.Optional[bool] = None):
     ''' Reset viewable area to show full strips range
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -639,12 +639,12 @@ def view_all(override_context: typing.Union[typing.
 def view_frame(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None):
+               undo: typing.Optional[bool] = None):
     ''' Move the view to the current frame
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -653,12 +653,12 @@ def view_frame(override_context: typing.
 def view_selected(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None):
+                  undo: typing.Optional[bool] = None):
     ''' Reset viewable area to show selected strips range
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
