@@ -43,11 +43,11 @@ def connect(override_context: typing.Union[typing.
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: typing.Optional[bool]
-    :param con_type: Type, Type of generated constraint * ``FIXED`` Fixed, Glue rigid bodies together. * ``POINT`` Point, Constrain rigid bodies to move around common pivot point. * ``HINGE`` Hinge, Restrict rigid body rotation to one axis. * ``SLIDER`` Slider, Restrict rigid body translation to one axis. * ``PISTON`` Piston, Restrict rigid body translation and rotation to one axis. * ``GENERIC`` Generic, Restrict translation and rotation to specified axes. * ``GENERIC_SPRING`` Generic Spring, Restrict translation and rotation to specified axes with springs. * ``MOTOR`` Motor, Drive rigid body around or along an axis.
+    :param con_type: Type, Type of generated constraint * ``FIXED`` Fixed -- Glue rigid bodies together. * ``POINT`` Point -- Constrain rigid bodies to move around common pivot point. * ``HINGE`` Hinge -- Restrict rigid body rotation to one axis. * ``SLIDER`` Slider -- Restrict rigid body translation to one axis. * ``PISTON`` Piston -- Restrict rigid body translation and rotation to one axis. * ``GENERIC`` Generic -- Restrict translation and rotation to specified axes. * ``GENERIC_SPRING`` Generic Spring -- Restrict translation and rotation to specified axes with springs. * ``MOTOR`` Motor -- Drive rigid body around or along an axis.
     :type con_type: typing.Optional[typing.Any]
-    :param pivot_type: Location, Constraint pivot location * ``CENTER`` Center, Pivot location is between the constrained rigid bodies. * ``ACTIVE`` Active, Pivot location is at the active object position. * ``SELECTED`` Selected, Pivot location is at the selected object position.
+    :param pivot_type: Location, Constraint pivot location * ``CENTER`` Center -- Pivot location is between the constrained rigid bodies. * ``ACTIVE`` Active -- Pivot location is at the active object position. * ``SELECTED`` Selected -- Pivot location is at the selected object position.
     :type pivot_type: typing.Optional[typing.Any]
-    :param connection_pattern: Connection Pattern, Pattern used to connect objects * ``SELECTED_TO_ACTIVE`` Selected to Active, Connect selected objects to the active object. * ``CHAIN_DISTANCE`` Chain by Distance, Connect objects as a chain based on distance, starting at the active object.
+    :param connection_pattern: Connection Pattern, Pattern used to connect objects * ``SELECTED_TO_ACTIVE`` Selected to Active -- Connect selected objects to the active object. * ``CHAIN_DISTANCE`` Chain by Distance -- Connect objects as a chain based on distance, starting at the active object.
     :type connection_pattern: typing.Optional[typing.Any]
     '''
 
@@ -65,7 +65,7 @@ def constraint_add(override_context: typing.
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: typing.Optional[bool]
-    :param type: Rigid Body Constraint Type * ``FIXED`` Fixed, Glue rigid bodies together. * ``POINT`` Point, Constrain rigid bodies to move around common pivot point. * ``HINGE`` Hinge, Restrict rigid body rotation to one axis. * ``SLIDER`` Slider, Restrict rigid body translation to one axis. * ``PISTON`` Piston, Restrict rigid body translation and rotation to one axis. * ``GENERIC`` Generic, Restrict translation and rotation to specified axes. * ``GENERIC_SPRING`` Generic Spring, Restrict translation and rotation to specified axes with springs. * ``MOTOR`` Motor, Drive rigid body around or along an axis.
+    :param type: Rigid Body Constraint Type * ``FIXED`` Fixed -- Glue rigid bodies together. * ``POINT`` Point -- Constrain rigid bodies to move around common pivot point. * ``HINGE`` Hinge -- Restrict rigid body rotation to one axis. * ``SLIDER`` Slider -- Restrict rigid body translation to one axis. * ``PISTON`` Piston -- Restrict rigid body translation and rotation to one axis. * ``GENERIC`` Generic -- Restrict translation and rotation to specified axes. * ``GENERIC_SPRING`` Generic Spring -- Restrict translation and rotation to specified axes with springs. * ``MOTOR`` Motor -- Drive rigid body around or along an axis.
     :type type: typing.Optional[typing.Any]
     '''
 
@@ -118,7 +118,7 @@ def object_add(override_context: typing.
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: typing.Optional[bool]
-    :param type: Rigid Body Type * ``ACTIVE`` Active, Object is directly controlled by simulation results. * ``PASSIVE`` Passive, Object is directly controlled by animation system.
+    :param type: Rigid Body Type * ``ACTIVE`` Active -- Object is directly controlled by simulation results. * ``PASSIVE`` Passive -- Object is directly controlled by animation system.
     :type type: typing.Optional[typing.Any]
     '''
 
@@ -164,7 +164,7 @@ def objects_add(override_context: typing.
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: typing.Optional[bool]
-    :param type: Rigid Body Type * ``ACTIVE`` Active, Object is directly controlled by simulation results. * ``PASSIVE`` Passive, Object is directly controlled by animation system.
+    :param type: Rigid Body Type * ``ACTIVE`` Active -- Object is directly controlled by simulation results. * ``PASSIVE`` Passive -- Object is directly controlled by animation system.
     :type type: typing.Optional[typing.Any]
     '''
 
@@ -196,7 +196,7 @@ def shape_change(override_context: typing.
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: typing.Optional[bool]
-    :param type: Rigid Body Shape * ``BOX`` Box, Box-like shapes (i.e. cubes), including planes (i.e. ground planes). * ``SPHERE`` Sphere. * ``CAPSULE`` Capsule. * ``CYLINDER`` Cylinder. * ``CONE`` Cone. * ``CONVEX_HULL`` Convex Hull, A mesh-like surface encompassing (i.e. shrinkwrap over) all vertices (best results with fewer vertices). * ``MESH`` Mesh, Mesh consisting of triangles only, allowing for more detailed interactions than convex hulls. * ``COMPOUND`` Compound Parent, Combines all of its direct rigid body children into one rigid object.
+    :param type: Rigid Body Shape * ``BOX`` Box -- Box-like shapes (i.e. cubes), including planes (i.e. ground planes). * ``SPHERE`` Sphere. * ``CAPSULE`` Capsule. * ``CYLINDER`` Cylinder. * ``CONE`` Cone. * ``CONVEX_HULL`` Convex Hull -- A mesh-like surface encompassing (i.e. shrinkwrap over) all vertices (best results with fewer vertices). * ``MESH`` Mesh -- Mesh consisting of triangles only, allowing for more detailed interactions than convex hulls. * ``COMPOUND`` Compound Parent -- Combines all of its direct rigid body children into one rigid object.
     :type type: typing.Optional[typing.Any]
     '''
 
