@@ -1,7 +1,6 @@
 import sys
 import typing
 import bpy.types
-import mathutils
 
 GenericType = typing.TypeVar("GenericType")
 
@@ -9,12 +8,12 @@ GenericType = typing.TypeVar("GenericType")
 def assign_default_button(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
-                          undo: bool = None):
+                          undo: typing.Optional[bool] = None):
     ''' Set this property's current value as the new default
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -23,16 +22,16 @@ def assign_default_button(override_context: typing.
 def button_execute(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   skip_depressed: bool = False):
+                   skip_depressed: typing.Union[bool, typing.Any] = False):
     ''' Presses active button
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param skip_depressed: Skip Depressed
-    :type skip_depressed: bool
+    :type skip_depressed: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -41,12 +40,12 @@ def button_execute(override_context: typing.
 def button_string_clear(override_context: typing.
                         Union[typing.Dict, 'bpy.types.Context'] = None,
                         execution_context: typing.Union[str, int] = None,
-                        undo: bool = None):
+                        undo: typing.Optional[bool] = None):
     ''' Unsets the text of the active button
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -55,12 +54,12 @@ def button_string_clear(override_context: typing.
 def copy_as_driver_button(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
-                          undo: bool = None):
+                          undo: typing.Optional[bool] = None):
     ''' Create a new driver with this property as input, and copy it to the clipboard. Use Paste Driver to add it to the target property, or Paste Driver Variables to extend an existing driver
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -69,16 +68,16 @@ def copy_as_driver_button(override_context: typing.
 def copy_data_path_button(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
-                          undo: bool = None,
+                          undo: typing.Optional[bool] = None,
                           *,
-                          full_path: bool = False):
+                          full_path: typing.Union[bool, typing.Any] = False):
     ''' Copy the RNA data path for this property to the clipboard
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param full_path: full_path, Copy full data path
-    :type full_path: bool
+    :type full_path: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -88,12 +87,12 @@ def copy_python_command_button(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: bool = None):
+        undo: typing.Optional[bool] = None):
     ''' Copy the Python command matching this button
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -102,40 +101,37 @@ def copy_python_command_button(
 def copy_to_selected_button(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
-                            undo: bool = None,
+                            undo: typing.Optional[bool] = None,
                             *,
-                            all: bool = True):
+                            all: typing.Union[bool, typing.Any] = True):
     ''' Copy property from this object to selected objects or bones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param all: All, Copy to selected all elements of the array
-    :type all: bool
+    :type all: typing.Union[bool, typing.Any]
     '''
 
     pass
 
 
-def drop_color(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        color: typing.Union[typing.List[float], typing.
-                            Tuple[float, float, float], 'mathutils.Vector'] = (
-                                0.0, 0.0, 0.0),
-        gamma: bool = False):
+def drop_color(override_context: typing.
+               Union[typing.Dict, 'bpy.types.Context'] = None,
+               execution_context: typing.Union[str, int] = None,
+               undo: typing.Optional[bool] = None,
+               *,
+               color: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
+               gamma: typing.Union[bool, typing.Any] = False):
     ''' Drop colors to buttons
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param color: Color, Source color
-    :type color: typing.Union[typing.List[float], typing.Tuple[float, float, float], 'mathutils.Vector']
+    :type color: typing.Optional[typing.Any]
     :param gamma: Gamma Corrected, The source color is gamma corrected
-    :type gamma: bool
+    :type gamma: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -144,16 +140,16 @@ def drop_color(
 def drop_name(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None,
+              undo: typing.Optional[bool] = None,
               *,
-              string: str = ""):
+              string: typing.Union[str, typing.Any] = ""):
     ''' Drop name to button
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param string: String, The string value to drop into the button
-    :type string: str
+    :type string: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -162,12 +158,12 @@ def drop_name(override_context: typing.Union[typing.
 def editsource(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None):
+               undo: typing.Optional[bool] = None):
     ''' Edit UI source code of the active button
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -176,12 +172,12 @@ def editsource(override_context: typing.
 def edittranslation_init(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: bool = None):
+                         undo: typing.Optional[bool] = None):
     ''' Edit i18n in current language for the active button
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -190,12 +186,12 @@ def edittranslation_init(override_context: typing.
 def eyedropper_color(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
+                     undo: typing.Optional[bool] = None):
     ''' Sample a color from the Blender window to store in a property
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -204,12 +200,12 @@ def eyedropper_color(override_context: typing.
 def eyedropper_colorramp(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: bool = None):
+                         undo: typing.Optional[bool] = None):
     ''' Sample a color band
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -219,12 +215,12 @@ def eyedropper_colorramp_point(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: bool = None):
+        undo: typing.Optional[bool] = None):
     ''' Point-sample a color band
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -233,30 +229,31 @@ def eyedropper_colorramp_point(
 def eyedropper_depth(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
+                     undo: typing.Optional[bool] = None):
     ''' Sample depth from the 3D view
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
 
 
-def eyedropper_driver(override_context: typing.
-                      Union[typing.Dict, 'bpy.types.Context'] = None,
-                      execution_context: typing.Union[str, int] = None,
-                      undo: bool = None,
-                      *,
-                      mapping_type: typing.Union[str, int] = 'SINGLE_MANY'):
+def eyedropper_driver(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: typing.Optional[bool] = None,
+        *,
+        mapping_type: typing.Optional[typing.Any] = 'SINGLE_MANY'):
     ''' Pick a property to use as a driver target
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
-    :param mapping_type: Mapping Type, Method used to match target and driven properties * SINGLE_MANY All from Target -- Drive all components of this property using the target picked. * DIRECT Single from Target -- Drive this component of this property using the target picked. * MATCH Match Indices -- Create drivers for each pair of corresponding elements. * NONE_ALL Manually Create Later -- Create drivers for all properties without assigning any targets yet. * NONE_SINGLE Manually Create Later (Single) -- Create driver for this property only and without assigning any targets yet.
-    :type mapping_type: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    :param mapping_type: Mapping Type, Method used to match target and driven properties * ``SINGLE_MANY`` All from Target -- Drive all components of this property using the target picked. * ``DIRECT`` Single from Target -- Drive this component of this property using the target picked. * ``MATCH`` Match Indices -- Create drivers for each pair of corresponding elements. * ``NONE_ALL`` Manually Create Later -- Create drivers for all properties without assigning any targets yet. * ``NONE_SINGLE`` Manually Create Later (Single) -- Create driver for this property only and without assigning any targets yet.
+    :type mapping_type: typing.Optional[typing.Any]
     '''
 
     pass
@@ -265,16 +262,16 @@ def eyedropper_driver(override_context: typing.
 def eyedropper_gpencil_color(override_context: typing.
                              Union[typing.Dict, 'bpy.types.Context'] = None,
                              execution_context: typing.Union[str, int] = None,
-                             undo: bool = None,
+                             undo: typing.Optional[bool] = None,
                              *,
-                             mode: typing.Union[str, int] = 'MATERIAL'):
+                             mode: typing.Optional[typing.Any] = 'MATERIAL'):
     ''' Sample a color from the Blender Window and create Grease Pencil material
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param mode: Mode
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Optional[typing.Any]
     '''
 
     pass
@@ -283,12 +280,12 @@ def eyedropper_gpencil_color(override_context: typing.
 def eyedropper_id(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None):
+                  undo: typing.Optional[bool] = None):
     ''' Sample a data-block from the 3D View to store in a property
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -297,12 +294,12 @@ def eyedropper_id(override_context: typing.
 def jump_to_target_button(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
-                          undo: bool = None):
+                          undo: typing.Optional[bool] = None):
     ''' Switch to the target object or bone
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -311,12 +308,12 @@ def jump_to_target_button(override_context: typing.
 def list_start_filter(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
-                      undo: bool = None):
+                      undo: typing.Optional[bool] = None):
     ''' Start entering filter text for the list in focus
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -325,16 +322,16 @@ def list_start_filter(override_context: typing.
 def override_remove_button(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
-                           undo: bool = None,
+                           undo: typing.Optional[bool] = None,
                            *,
-                           all: bool = True):
+                           all: typing.Union[bool, typing.Any] = True):
     ''' Remove an override operation
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param all: All, Reset to default values all elements of the array
-    :type all: bool
+    :type all: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -343,19 +340,19 @@ def override_remove_button(override_context: typing.
 def override_type_set_button(override_context: typing.
                              Union[typing.Dict, 'bpy.types.Context'] = None,
                              execution_context: typing.Union[str, int] = None,
-                             undo: bool = None,
+                             undo: typing.Optional[bool] = None,
                              *,
-                             all: bool = True,
-                             type: typing.Union[str, int] = 'REPLACE'):
+                             all: typing.Union[bool, typing.Any] = True,
+                             type: typing.Optional[typing.Any] = 'REPLACE'):
     ''' Create an override operation, or set the type of an existing one
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param all: All, Reset to default values all elements of the array
-    :type all: bool
-    :param type: Type, Type of override operation * NOOP NoOp -- 'No-Operation', place holder preventing automatic override to ever affect the property. * REPLACE Replace -- Completely replace value from linked data by local one. * DIFFERENCE Difference -- Store difference to linked data value. * FACTOR Factor -- Store factor to linked data value (useful e.g. for scale).
-    :type type: typing.Union[str, int]
+    :type all: typing.Union[bool, typing.Any]
+    :param type: Type, Type of override operation * ``NOOP`` NoOp -- 'No-Operation', place holder preventing automatic override to ever affect the property. * ``REPLACE`` Replace -- Completely replace value from linked data by local one. * ``DIFFERENCE`` Difference -- Store difference to linked data value. * ``FACTOR`` Factor -- Store factor to linked data value (useful e.g. for scale).
+    :type type: typing.Optional[typing.Any]
     '''
 
     pass
@@ -364,12 +361,12 @@ def override_type_set_button(override_context: typing.
 def reloadtranslation(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
-                      undo: bool = None):
+                      undo: typing.Optional[bool] = None):
     ''' Force a full reload of UI translation
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -378,16 +375,16 @@ def reloadtranslation(override_context: typing.
 def reset_default_button(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: bool = None,
+                         undo: typing.Optional[bool] = None,
                          *,
-                         all: bool = True):
+                         all: typing.Union[bool, typing.Any] = True):
     ''' Reset this property's value to its default value
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param all: All, Reset to default values all elements of the array
-    :type all: bool
+    :type all: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -396,12 +393,12 @@ def reset_default_button(override_context: typing.
 def tree_view_drop(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None):
+                   undo: typing.Optional[bool] = None):
     ''' Drag and drop items onto a tree item
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -410,12 +407,12 @@ def tree_view_drop(override_context: typing.
 def tree_view_item_rename(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
-                          undo: bool = None):
+                          undo: typing.Optional[bool] = None):
     ''' Rename the active item in the tree
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -424,12 +421,12 @@ def tree_view_item_rename(override_context: typing.
 def unset_property_button(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
-                          undo: bool = None):
+                          undo: typing.Optional[bool] = None):
     ''' Clear the property and use default or generated value in operators
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
