@@ -10,14 +10,29 @@ def edge_pan(override_context: typing.Union[typing.
              execution_context: typing.Union[str, int] = None,
              undo: typing.Optional[bool] = None,
              *,
-             outside_padding: typing.Optional[typing.Any] = 0):
+             inside_padding: typing.Optional[typing.Any] = 1.0,
+             outside_padding: typing.Optional[typing.Any] = 0.0,
+             speed_ramp: typing.Optional[typing.Any] = 1.0,
+             max_speed: typing.Optional[typing.Any] = 500.0,
+             delay: typing.Optional[typing.Any] = 1.0,
+             zoom_influence: typing.Optional[typing.Any] = 0.0):
     ''' Pan the view when the mouse is held at an edge
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: typing.Optional[bool]
-    :param outside_padding: Outside Padding, Padding around the region in UI units within which panning is activated (0 to disable boundary)
+    :param inside_padding: Inside Padding, Inside distance in UI units from the edge of the region within which to start panning
+    :type inside_padding: typing.Optional[typing.Any]
+    :param outside_padding: Outside Padding, Outside distance in UI units from the edge of the region at which to stop panning
     :type outside_padding: typing.Optional[typing.Any]
+    :param speed_ramp: Speed Ramp, Width of the zone in UI units where speed increases with distance from the edge
+    :type speed_ramp: typing.Optional[typing.Any]
+    :param max_speed: Max Speed, Maximum speed in UI units per second
+    :type max_speed: typing.Optional[typing.Any]
+    :param delay: Delay, Delay in seconds before maximum speed is reached
+    :type delay: typing.Optional[typing.Any]
+    :param zoom_influence: Zoom Influence, Influence of the zoom factor on scroll speed
+    :type zoom_influence: typing.Optional[typing.Any]
     '''
 
     pass
