@@ -43,7 +43,7 @@ def axis_conversion(from_forward='Y', from_up='Z', to_forward='Y', to_up='Z'):
 
 def axis_conversion_ensure(operator: 'bpy.types.Operator', forward_attr: str,
                            up_attr: str) -> bool:
-    ''' Function to ensure an operator has valid axis conversion settings, intended to be used from bpy.types.Operator.check .
+    ''' Function to ensure an operator has valid axis conversion settings, intended to be used from `bpy.types.Operator.check`.
 
     :param operator: the operator to access axis attributes from.
     :type operator: 'bpy.types.Operator'
@@ -60,15 +60,15 @@ def axis_conversion_ensure(operator: 'bpy.types.Operator', forward_attr: str,
 
 def create_derived_objects(
         depsgraph: 'bpy.types.Depsgraph',
-        objects: typing.List['bpy.types.Object']) -> typing.Dict:
+        objects: typing.Sequence['bpy.types.Object']) -> typing.Dict:
     ''' This function takes a sequence of objects, returning their instances.
 
     :param depsgraph: The evaluated depsgraph.
     :type depsgraph: 'bpy.types.Depsgraph'
     :param objects: A sequencer of objects.
-    :type objects: typing.List['bpy.types.Object']
+    :type objects: typing.Sequence['bpy.types.Object']
     :rtype: typing.Dict
-    :return: A dictionary where each key is an object from objects , values are lists of ( bpy.types.Object , mathutils.Matrix ) tuples representing instances.
+    :return: A dictionary where each key is an object from `objects`, values are lists of (`bpy.types.Object`, `mathutils.Matrix`) tuples representing instances.
     '''
 
     pass
@@ -82,13 +82,14 @@ def orientation_helper(axis_forward='Y', axis_up='Z'):
     pass
 
 
-def path_reference(filepath: str,
-                   base_src: str,
-                   base_dst: str,
-                   mode: str = 'AUTO',
-                   copy_subdir: str = '',
-                   copy_set: typing.Set = None,
-                   library: 'bpy.types.Library' = None) -> str:
+def path_reference(
+        filepath: str,
+        base_src: str,
+        base_dst: str,
+        mode: str = 'AUTO',
+        copy_subdir: str = '',
+        copy_set: typing.Set = None,
+        library: typing.Optional['bpy.types.Library'] = None) -> str:
     ''' Return a filepath relative to a destination directory, for use with exporters.
 
     :param filepath: the file path to return, supporting blenders relative '//' prefix.
@@ -104,7 +105,7 @@ def path_reference(filepath: str,
     :param copy_set: collect from/to pairs when mode='COPY', pass to *path_reference_copy* when exporting is done.
     :type copy_set: typing.Set
     :param library: The library this path is relative to.
-    :type library: 'bpy.types.Library'
+    :type library: typing.Optional['bpy.types.Library']
     :rtype: str
     :return: the new filepath.
     '''
@@ -113,31 +114,34 @@ def path_reference(filepath: str,
 
 
 def path_reference_copy(copy_set: typing.Set,
-                        report='<built-in function print>'):
+                        report: typing.Any = '<built-in function print>'):
     ''' Execute copying files of path_reference
 
     :param copy_set: set of (from, to) pairs to copy.
     :type copy_set: typing.Set
     :param report: function used for reporting warnings, takes a string argument.
+    :type report: typing.Any
     '''
 
     pass
 
 
-def unique_name(key,
+def unique_name(key: typing.Any,
                 name: str,
                 name_dict: typing.Dict,
                 name_max=-1,
-                clean_func=None,
+                clean_func: typing.Any = None,
                 sep: str = '.'):
     ''' Helper function for storing unique names which may have special characters stripped and restricted to a maximum length.
 
     :param key: unique item this name belongs to, name_dict[key] will be reused when available. This can be the object, mesh, material, etc instance its self.
+    :type key: typing.Any
     :param name: The name used to create a unique value in *name_dict*.
     :type name: str
     :param name_dict: This is used to cache namespace to ensure no collisions occur, this should be an empty dict initially and only modified by this function.
     :type name_dict: typing.Dict
     :param clean_func: Function to call on *name* before creating a unique value.
+    :type clean_func: typing.Any
     :param sep: Separator to use when between the name and a number when a duplicate name is found.
     :type sep: str
     '''
