@@ -1,6 +1,8 @@
 import sys
 import typing
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class RestrictBlend:
     context = None
@@ -11,7 +13,7 @@ class RestrictBlend:
 
 
 class _RestrictContext:
-    user_preferences = None
+    preferences = None
     ''' '''
 
     window_manager = None
