@@ -19,10 +19,11 @@ def load(filepath: str) -> 'imbuf.types.ImBuf':
     pass
 
 
-def new(size) -> 'imbuf.types.ImBuf':
+def new(size: typing.Any) -> 'imbuf.types.ImBuf':
     ''' Load a new image.
 
     :param size: The size of the image in pixels.
+    :type size: typing.Any
     :rtype: 'imbuf.types.ImBuf'
     :return: the newly loaded image.
     '''
