@@ -43,6 +43,12 @@ class Color:
     :type: bool
     '''
 
+    is_valid: bool = None
+    ''' True when the owner of this data is valid.
+
+    :type: bool
+    '''
+
     is_wrapped: bool = None
     ''' True when this object wraps external data (read-only).
 
@@ -218,6 +224,12 @@ class Euler:
     :type: bool
     '''
 
+    is_valid: bool = None
+    ''' True when the owner of this data is valid.
+
+    :type: bool
+    '''
+
     is_wrapped: bool = None
     ''' True when this object wraps external data (read-only).
 
@@ -358,6 +370,12 @@ class Matrix:
     :type: bool
     '''
 
+    is_valid: bool = None
+    ''' True when the owner of this data is valid.
+
+    :type: bool
+    '''
+
     is_wrapped: bool = None
     ''' True when this object wraps external data (read-only).
 
@@ -408,6 +426,25 @@ class Matrix:
         '''
         pass
 
+    @classmethod
+    def LocRotScale(
+            cls, location: typing.Optional['Vector'],
+            rotation: typing.Union[typing.Sequence[float], 'Quaternion', typing
+                                   .Sequence[float], 'Euler'],
+            scale: typing.Optional['Vector']) -> 'Matrix':
+        ''' Create a matrix combining translation, rotation and scale, acting as the inverse of the decompose() method. Any of the inputs may be replaced with None if not needed.
+
+        :param location: The translation component.
+        :type location: typing.Optional['Vector']
+        :param rotation: The rotation component.
+        :type rotation: typing.Union[typing.Sequence[float], 'Quaternion', typing.Sequence[float], 'Euler']
+        :param scale: The scale component.
+        :type scale: typing.Optional['Vector']
+        :rtype: 'Matrix'
+        :return: Combined transformation matrix.
+        '''
+        pass
+
     @classmethod
     def OrthoProjection(
             cls, axis: typing.Union[str, typing.Sequence[float], 'Vector'],
@@ -835,6 +872,12 @@ class Quaternion:
     :type: bool
     '''
 
+    is_valid: bool = None
+    ''' True when the owner of this data is valid.
+
+    :type: bool
+    '''
+
     is_wrapped: bool = None
     ''' True when this object wraps external data (read-only).
 
@@ -1219,6 +1262,12 @@ class Vector:
     :type: bool
     '''
 
+    is_valid: bool = None
+    ''' True when the owner of this data is valid.
+
+    :type: bool
+    '''
+
     is_wrapped: bool = None
     ''' True when this object wraps external data (read-only).
 
@@ -2303,7 +2352,7 @@ class Vector:
         pass
 
     @classmethod
-    def Range(cls, start: int = 0, stop: int = -1, step: int = 1):
+    def Range(cls, start: int, stop: int, step: int = 1):
         ''' Create a filled with a range of values.
 
         :param start: The start of the range used to fill the vector.
